@@ -23,10 +23,10 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 
 int main(int argc, char *argv[])
 {
-  Optionpk<string> image_opt("i","image","input image to analyse","");
+  Optionpk<std::string> image_opt("i","image","input image to analyse","");
   Optionpk<unsigned short>  band_opt("b", "band", "Band specific information", 0);
-  Optionpk<string> cell2bb_opt("c2b","cell2bb","convert cell code to geo coordinates of boundingbox (e.g. 32-AB)","");
-  Optionpk<string> cell2mid_opt("c2m","cell2mid","convert cell code to centre in geo coordinates (e.g. 32-AB)","");
+  Optionpk<std::string> cell2bb_opt("c2b","cell2bb","convert cell code to geo coordinates of boundingbox (e.g. 32-AB)","");
+  Optionpk<std::string> cell2mid_opt("c2m","cell2mid","convert cell code to centre in geo coordinates (e.g. 32-AB)","");
   Optionpk<bool> refpixel_opt("\0", "ref", "get reference pixel (lower left corner of centre of gravity pixel)", false);
   Optionpk<double> maskValue_opt("m", "mask", "mask value(s) for no data to calculate reference pixel in image",0);
   Optionpk<int> dx_opt("dx","dx","resolution",250);
@@ -48,7 +48,7 @@ int main(int argc, char *argv[])
     x_opt.retrieveOption(argc,argv);
     y_opt.retrieveOption(argc,argv);
   }
-  catch(string predefinedString){
+  catch(std::string predefinedString){
     std::cout << predefinedString << std::endl;
     exit(0);
   }
@@ -62,17 +62,17 @@ int main(int argc, char *argv[])
     int theULX, theULY, theLRX, theLRY;
     egcs.setLevel(egcs.cell2level(cell2bb_opt[0]));
     egcs.cell2bb(cell2bb_opt[0],theULX,theULY,theLRX,theLRY);
-    cout << setprecision(12) << "--ulx=" << theULX << " --uly=" << theULY << " --lrx=" << theLRX << " --lry=" << theLRY << endl;
+    std::cout << std::setprecision(12) << "--ulx=" << theULX << " --uly=" << theULY << " --lrx=" << theLRX << " --lry=" << theLRY << std::endl;
   }
   if(cell2mid_opt[0]!=""){
     double midX, midY;
     egcs.setLevel(egcs.cell2level(cell2mid_opt[0]));
     egcs.cell2mid(cell2mid_opt[0],midX,midY);
-    cout << setprecision(12) << "-x=" << midX << " -y=" << midY << endl;
+    std::cout << std::setprecision(12) << "-x=" << midX << " -y=" << midY << std::endl;
   }
   if(geo2cell_opt[0]){
     egcs.setLevel(egcs.res2level(dx_opt[0]));
-    cout << egcs.geo2cell(x_opt[0],y_opt[0]) << endl;
+    std::cout << egcs.geo2cell(x_opt[0],y_opt[0]) << std::endl;
   }
   if(image_opt[0]!=""){
     ImgReaderGdal imgReader;
@@ -84,16 +84,16 @@ int main(int argc, char *argv[])
       // if(verbose_opt[0]){
       //   vector<double> noData;
       //   imgReader.getNoDataValues(noData,band_opt[0]);
-      //   cout << "number of no data values: " << noData.size() << endl;
+      //   std::cout << "number of no data values: " << noData.size() << std::endl;
       // }
       double refX,refY;
       //get centre of reference (centre of gravity) pixel in image
       imgReader.getRefPix(refX,refY,band_opt[0]);
-      cout << setprecision(12) << "--x " << refX << " --y " << refY << endl;
+      std::cout << std::setprecision(12) << "--x " << refX << " --y " << refY << std::endl;
       egcs.setLevel(egcs.res2level(imgReader.getDeltaX()));
       // unsigned short theLevel=egcs.getLevel(imgReader.getDeltaX());
       // egcs.setLevel(theLevel);
-      cout << "cell code at level " << egcs.getLevel() << " (resolution is " << egcs.getResolution() << "): " << egcs.geo2cell(refX,refY) << endl;
+      std::cout << "cell code at level " << egcs.getLevel() << " (resolution is " << egcs.getResolution() << "): " << egcs.geo2cell(refX,refY) << std::endl;
     }
   }
 }
