@@ -32,7 +32,7 @@ int main(int argc,char **argv) {
   Optionpk<double> maxRef_opt("maxref", "maxref", "Sets maximum for histogram of reference image");
   Optionpk<double> minInput_opt("mininput", "mininput", "Sets minimum for histogram of input image");
   Optionpk<double> maxInput_opt("maxinput", "maxinput", "Sets maximum for histogram of input image");
-  Optionpk<double> nodata_opt("nodata", "nodata", "Sets no data value(s) for calculations (flags in input image)");
+  Optionpk<double> nodata_opt("nodata", "nodata", "Sets no data value(s) for calculations (nodata values in input image)");
   Optionpk<std::string> method_opt("m", "method", "enhancement method (histmatch)", "histmatch");
   // Optionpk<std::string> wavelet_type_opt("wt", "wavelet", "wavelet type: daubechies,daubechies_centered, haar, haar_centered, bspline, bspline_centered", "daubechies");
   // Optionpk<int> family_opt("wf", "family", "wavelet family (vanishing moment, see also http://www.gnu.org/software/gsl/manual/html_node/DWT-Initialization.html)", 4);
