@@ -25,18 +25,18 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 
 using namespace std;
 int main(int argc,char **argv) {
-  Optionpk<string>  input_opt("i", "input", "Input image file", "");
-  Optionpk<short>  band_opt("b", "band", "band(s) used for mask", 0);
+  Optionpk<string> input_opt("i", "input", "Input image file");
+  Optionpk<short> band_opt("b", "band", "band(s) used for mask", 0);
   Optionpk<double> min_opt("min", "min", "Values smaller than min threshold(s) are masked as invalid. Use one threshold for each band", 0);
   Optionpk<double> max_opt("max", "max", "Values greater than max threshold(s) are masked as invalid. Use one threshold for each band", 0);
-  Optionpk<string>  operator_opt("p", "operator", "Operator: [AND,OR].", "OR");
-  Optionpk<unsigned short> valid_opt("t", "tvalue", "value(s) for valid pixels: between min and max", 1);
-  Optionpk<unsigned short> invalid_opt("f", "fvalue", "value(s) for invalid pixels: not between min and max", 0);
-  Optionpk<string> output_opt("o", "output", "Output mask file", "");
-  Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "Byte");
-  Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image", "");
+  Optionpk<string> operator_opt("p", "operator", "Operator: [AND,OR].", "OR");
+  Optionpk<unsigned short> data_opt("data", "data", "value(s) for valid pixels: between min and max", 1);
+  Optionpk<unsigned short> nodata_opt("nodata", "nodata", "value(s) for invalid pixels: not between min and max", 0);
+  Optionpk<string> output_opt("o", "output", "Output mask file");
+  Optionpk<string> otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "Byte");
+  Optionpk<string> oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
-  Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)", "");
+  Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
   Optionpk<short> verbose_opt("v", "verbose", "verbose", 0);
 
   bool doProcess;//stop process when program was invoked with help option (-h --help)
@@ -46,8 +46,8 @@ int main(int argc,char **argv) {
     min_opt.retrieveOption(argc,argv);
     max_opt.retrieveOption(argc,argv);
     operator_opt.retrieveOption(argc,argv);
-    valid_opt.retrieveOption(argc,argv);
-    invalid_opt.retrieveOption(argc,argv);
+    data_opt.retrieveOption(argc,argv);
+    nodata_opt.retrieveOption(argc,argv);
     output_opt.retrieveOption(argc,argv);
     otype_opt.retrieveOption(argc,argv);
     oformat_opt.retrieveOption(argc,argv);
@@ -88,6 +88,7 @@ int main(int argc,char **argv) {
       cout << "Output pixel type:  " << GDALGetDataTypeName(theType) << endl;
   }
 
+  assert(input_opt.size());
   ImgReaderGdal imgReader(input_opt[0]);
   assert(band_opt.size()>=0);
   assert(band_opt.size()<=imgReader.nrOfBand());
@@ -96,8 +97,8 @@ int main(int argc,char **argv) {
     min_opt.push_back(min_opt[0]);
   while(band_opt.size()>max_opt.size())
     max_opt.push_back(max_opt[0]);
-  while(min_opt.size()>valid_opt.size())
-    valid_opt.push_back(valid_opt[0]);
+  while(min_opt.size()>data_opt.size())
+    data_opt.push_back(data_opt[0]);
   assert(min_opt.size()==max_opt.size());
   if(verbose_opt[0]){
     cout << "min,max values: ";
@@ -121,15 +122,16 @@ int main(int argc,char **argv) {
       cout << "Using data type from input image: " << GDALGetDataTypeName(theType) << endl;
   }
   string imageType=imgReader.getImageType();
-  if(oformat_opt[0]!="")//default
+  if(oformat_opt.size())//default
     imageType=oformat_opt[0];
   if(option_opt.findSubstring("INTERLEAVE=")==option_opt.end()){
     string theInterleave="INTERLEAVE=";
     theInterleave+=imgReader.getInterleave();
     option_opt.push_back(theInterleave);
   }
+  assert(output_opt.size());
   imgWriter.open(output_opt[0],imgReader.nrOfCol(),imgReader.nrOfRow(),1,theType,imageType,option_opt);
-  if(colorTable_opt[0]!=""){
+  if(colorTable_opt.size()){
     if(colorTable_opt[0]!="none")
       imgWriter.setColorTable(colorTable_opt[0]);
   }
@@ -147,13 +149,13 @@ int main(int argc,char **argv) {
       imgReader.readData(lineBuffer[iband],GDT_Float32,irow,band_opt[iband]);
     for(int icol=0;icol<imgReader.nrOfCol();++icol){
       bool valid=(operator_opt[0]=="OR")?false:true;
-      unsigned short validValue=valid_opt[0];
+      unsigned short validValue=data_opt[0];
       for(int ivalid=0;ivalid<min_opt.size();++ivalid){
         bool validBand=false;
       // for(int iband=0;iband<band_opt.size();++iband){
         unsigned short theBand=(band_opt.size()==min_opt.size())? ivalid:0;
         if(lineBuffer[theBand][icol]>=min_opt[ivalid]&&lineBuffer[theBand][icol]<=max_opt[ivalid]){
-          validValue=valid_opt[ivalid];
+          validValue=data_opt[ivalid];
           validBand=true;
         }
         valid=(operator_opt[0]=="OR")?valid||validBand : valid&&validBand;
@@ -161,7 +163,7 @@ int main(int argc,char **argv) {
       if(valid)
 	writeBuffer[icol]=validValue;
       else
-	writeBuffer[icol]=invalid_opt[0];
+	writeBuffer[icol]=nodata_opt[0];
     }
     imgWriter.writeData(writeBuffer,GDT_Byte,irow);
     progress=(1.0+irow)/imgWriter.nrOfRow();
