@@ -54,7 +54,7 @@ ImgWriterOgr::ImgWriterOgr(const string& filename, ImgReaderOgr& imgReaderOgr, b
   copyFields(imgReaderOgr);
   if(copyData){
     OGRFeature *poFeature;
-    while( (poFeature = imgReaderOgr.getLayer()->GetNextFeature()) != NULL ){
+    while(true){// (poFeature = imgReaderOgr.getLayer()->GetNextFeature()) != NULL ){
       poFeature = imgReaderOgr.getLayer()->GetNextFeature();
       if( poFeature == NULL )
         break;
@@ -96,6 +96,14 @@ ImgWriterOgr::ImgWriterOgr(const string& filename, ImgReaderOgr& imgReaderOgr, b
 
 //---------------------------------------------------------------------------
 
+void ImgWriterOgr::open(const string& filename, ImgReaderOgr& imageReader)
+{
+  m_filename=filename;
+  setCodec(imageReader.getDriver());
+  createLayer(filename,imageReader.getProjection(),imageReader.getGeometryType(),NULL);
+  copyFields(imageReader);
+}
+
 void ImgWriterOgr::open(const string& filename, const string& imageType)
 {
   m_filename = filename;
@@ -394,13 +402,12 @@ int ImgWriterOgr::getFeatureCount() const
   return(getLayer()->GetFeatureCount());
 }
 
-int ImgWriterOgr::ascii2shape(const string& filename, const string &layername, const vector<string>& fieldName, const vector<OGRFieldType>& fieldType, short colX, short colY, const string& theProjection, const OGRwkbGeometryType& eGType)
+int ImgWriterOgr::ascii2ogr(const string& filename, const string &layername, const vector<string>& fieldName, const vector<OGRFieldType>& fieldType, short colX, short colY, const string& theProjection, const OGRwkbGeometryType& eGType, const char fs)
 {
   char     **papszOptions=NULL;
   createLayer(layername, theProjection, eGType, papszOptions);
   //create attribute fields that should appear on the layer. Fields must be added to the layer before any features are written. To create a field we initialize an OGRField object with the information about the field. In the case of Shapefiles, the field width and precision is significant in the creation of the output .dbf file, so we set it specifically, though generally the defaults are OK
   int ncol=fieldName.size();
-  assert(fieldName.size()==fieldType.size());
   assert(colX>=0);
   assert(colY>=0);
   assert(colX<ncol+2);
@@ -417,66 +424,135 @@ int ImgWriterOgr::ascii2shape(const string& filename, const string &layername, c
   OGRFeature *polyFeature;
   if(eGType!=wkbPoint)
     polyFeature=createFeature();
-  while(getline(fpoints,line)){
-    OGRFeature *pointFeature;
-    if(eGType==wkbPoint)
-      pointFeature=createFeature();
-    OGRPoint thePoint;
-    bool skip=false;
-    istringstream ist(line);
-    string value;
-    int colId=0;
-    int fieldId=0;
-    while(ist >> value){
-      if(colId==colX)
-	thePoint.setX(atof(value.c_str()));
-      else if(colId==colY)
-	thePoint.setY(atof(value.c_str()));
-      else{
-        switch(fieldType[fieldId]){
-        case(OFTReal):
-	  if(eGType==wkbPoint)
-	    pointFeature->SetField(fieldId,atof(value.c_str()));
-	  else if(firstPoint.IsEmpty())
-	    polyFeature->SetField(fieldId,atof(value.c_str()));
-          break;
-        case(OFTInteger):
-	  if(eGType==wkbPoint)
-	    pointFeature->SetField(fieldId,atoi(value.c_str()));
-	  else if(firstPoint.IsEmpty())
-	    polyFeature->SetField(fieldId,atof(value.c_str()));
-          break;
-        case(OFTString):
-	  if(eGType==wkbPoint)
-	    pointFeature->SetField(fieldId,value.c_str());
-	  else if(firstPoint.IsEmpty())
-	    polyFeature->SetField(fieldId,atof(value.c_str()));
-          break;
-        default:
-          break;
+
+
+  if(fs>' '&&fs<='~'){//field separator is a regular character (minimum ASCII code is space, maximum ASCII code is tilde)
+    string csvRecord;
+    while(getline(fpoints,csvRecord)){//read a line
+      OGRFeature *pointFeature;
+      if(eGType==wkbPoint)
+        pointFeature=createFeature();
+      OGRPoint thePoint;
+      bool skip=false;
+      istringstream csvstream(csvRecord);
+      string value;
+      int colId=0;
+      int fieldId=0;
+      while(getline(csvstream,value,fs)){//read a column
+        if(colId==colX)
+          thePoint.setX(atof(value.c_str()));
+        else if(colId==colY)
+          thePoint.setY(atof(value.c_str()));
+        else{
+          switch(fieldType[fieldId]){
+          case(OFTReal):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,atof(value.c_str()));
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          case(OFTInteger):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,atoi(value.c_str()));
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          case(OFTString):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,value.c_str());
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          default:
+            break;
+          }
+          ++fieldId;
         }
-        ++fieldId;
+        ++colId;
       }
-      ++colId;
-    }
-    if(colId!=fieldId+2){
-      ostringstream ess;
-      ess << "Error: colId = " << colId << " is different from fieldId+2 = " << fieldId;
-      throw(ess.str());
-    }
-    if(eGType==wkbPoint){
-      pointFeature->SetGeometry( &thePoint );
-      if(createFeature(pointFeature)!=OGRERR_NONE){
-	string errorString="Failed to create feature in shapefile";
-	throw(errorString);
-	OGRFeature::DestroyFeature( pointFeature );
+      if(colId!=fieldId+2){
+        ostringstream ess;
+        ess << "Error: colId = " << colId << " is different from fieldId+2 = " << fieldId;
+        throw(ess.str());
+      }
+      if(eGType==wkbPoint){
+        pointFeature->SetGeometry( &thePoint );
+        if(createFeature(pointFeature)!=OGRERR_NONE){
+          string errorString="Failed to create feature in shapefile";
+          throw(errorString);
+          OGRFeature::DestroyFeature( pointFeature );
+        }
+      }
+      else{
+        if(firstPoint.IsEmpty()){
+          firstPoint=thePoint;
+        }
+        theRing.addPoint(&thePoint);
       }
     }
-    else{
-      if(firstPoint.IsEmpty()){
-	firstPoint=thePoint;
+  }
+  else{//space or tab delimited fields
+    while(getline(fpoints,line)){
+      OGRFeature *pointFeature;
+      if(eGType==wkbPoint)
+        pointFeature=createFeature();
+      OGRPoint thePoint;
+      bool skip=false;
+      istringstream ist(line);
+      string value;
+      int colId=0;
+      int fieldId=0;
+      while(ist >> value){
+        if(colId==colX)
+          thePoint.setX(atof(value.c_str()));
+        else if(colId==colY)
+          thePoint.setY(atof(value.c_str()));
+        else{
+          switch(fieldType[fieldId]){
+          case(OFTReal):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,atof(value.c_str()));
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          case(OFTInteger):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,atoi(value.c_str()));
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          case(OFTString):
+            if(eGType==wkbPoint)
+              pointFeature->SetField(fieldId,value.c_str());
+            else if(firstPoint.IsEmpty())
+              polyFeature->SetField(fieldId,atof(value.c_str()));
+            break;
+          default:
+            break;
+          }
+          ++fieldId;
+        }
+        ++colId;
+      }
+      if(colId!=fieldId+2){
+        ostringstream ess;
+        ess << "Error: colId = " << colId << " is different from fieldId+2 = " << fieldId;
+        throw(ess.str());
+      }
+      if(eGType==wkbPoint){
+        pointFeature->SetGeometry( &thePoint );
+        if(createFeature(pointFeature)!=OGRERR_NONE){
+          string errorString="Failed to create feature in shapefile";
+          throw(errorString);
+          OGRFeature::DestroyFeature( pointFeature );
+        }
+      }
+      else{
+        if(firstPoint.IsEmpty()){
+          firstPoint=thePoint;
+        }
+        theRing.addPoint(&thePoint);
       }
-      theRing.addPoint(&thePoint);
     }
   }
   if(eGType!=wkbPoint){
